<template>
  <div class="app-container">
    <el-form
      ref="queryForm"
      :model="queryParams"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="当当账号" prop="dangAccount">
        <el-input
          v-model="queryParams.dangAccount"
          placeholder="请输入当当账号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="孔网账号" prop="fuziAccount">
        <el-input
          v-model="queryParams.fuziAccount"
          placeholder="请输入孔网账号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
        >搜索</el-button
        >
        <el-button
          icon="el-icon-refresh"
          size="mini"
          @click="resetQuery"
        >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          v-permission="['shop:shopAccount:add']"
          type="primary"
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
        >新增</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          v-permission="['shop:shopAccount:edit']"
          :disabled="single"
          type="success"
          icon="el-icon-edit"
          size="mini"
          @click="handleUpdate"
        >修改</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          v-permission="['shop:shopAccount:remove']"
          :disabled="multiple"
          type="danger"
          icon="el-icon-delete"
          size="mini"
          @click="handleDelete"
        >删除</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          v-permission="['shop:shopAccount:export']"
          type="warning"
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
        >导出</el-button
        >
      </el-col>
    </el-row>

    <el-table
      v-loading="loading"
      :data="accountList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column type="index" label="序号">
        <template slot-scope="scope">
          <span v-if="scope.$index < 9">0{{ scope.$index + 1 }}</span>
          <span v-else>{{ scope.$index + 1 }}</span>
        </template>
      </el-table-column>
      <el-table-column label="店铺id" align="center" prop="dangId" />
      <el-table-column label="店铺名称" align="center" prop="dangName" />
      <!-- <el-table-column label="运费模板" align="center" prop="dangTran" /> -->
      <!-- <el-table-column label="孔网id" align="center" prop="fuziId" /> -->
      <el-table-column label="孔网账号" align="center" prop="fuziAccount" />
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column label="管理员" align="center" prop="userName" />
      <el-table-column
        label="更新时间"
        align="center"
        prop="gmtUpdate"
        width="180"
      >
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.gmtUpdate) }}</span>
        </template>
      </el-table-column>
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            v-permission="['admin:shop:shopAccount:update']"
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdateData(scope.row)"
          >更新</el-button
          >
          <el-button
            v-permission="['shop:shopAccount:edit']"
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button
          >
          <el-button
            v-permission="['shop:shopAccount:remove']"
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
          >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改电商账户表对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px">
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-form-item v-show="!updateFlag" label="授权用户" prop="userId">
          <el-select v-model="form.userId" placeholder="请选择">
            <el-option
              v-for="item in userList"
              :key="item.value"
              :label="item.label"
              :value="item.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item v-show="!updateFlag" label="店铺id" prop="dangId">
          <el-input v-model="form.dangId" placeholder="请输入店铺id" />
        </el-form-item>
        <el-form-item v-show="!updateFlag" label="appkey" prop="dangAppKey">
          <el-input v-model="form.dangAppKey" placeholder="请输入appkey" />
        </el-form-item>
        <el-form-item v-show="!updateFlag" label="appsecret" prop="dangAppSecret">
          <el-input
            v-model="form.dangAppSecret"
            placeholder="请输appsecret"
          />
        </el-form-item>
        <el-form-item v-show="!updateFlag" label="session" prop="dangSession">
          <el-input v-model="form.dangSession" placeholder="session" />
        </el-form-item>
        <el-form-item v-show="!updateFlag" label="接口版本" prop="dangVersion">
          <el-input
            v-model="form.dangVersion"
            placeholder="请输入接口版本"
          />
        </el-form-item>
        <el-form-item label="店铺名称" prop="dangName">
          <el-input v-model="form.dangName" placeholder="请输入店铺名称" />
        </el-form-item>
        <!-- <el-form-item label="当当运费模板" prop="dangTran">
          <el-input v-model="form.dangTran" placeholder="请输入当当运费模板" />
        </el-form-item> -->
        <!-- <el-form-item label="孔网账号id" prop="fuziId">
          <el-input v-model="form.fuziId" placeholder="请输入孔网账号id" />
        </el-form-item> -->
        <el-form-item label="孔网账号" prop="fuziAccount">
          <el-input v-model="form.fuziAccount" placeholder="请输入孔网账号" />
        </el-form-item>
        <el-form-item label="孔网密码" prop="fuziPassword">
          <el-input
            v-model="form.fuziPassword"
            type="password"
            placeholder="请输入孔网密码"
          />
        </el-form-item>
        <el-form-item label="孔网cookie" prop="fuziCookie">
          <el-input
            v-model="form.fuziCookie"
            type="textarea"
            placeholder="请输入内容"
          />
        </el-form-item>
        <el-form-item label="教程" prop="remark">
          <el-button
            type="primary"
            @click="handleSee()"
          >查看设置方法</el-button
          >
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input
            v-model="form.remark"
            type="textarea"
            placeholder="请输入内容"
          />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listAccount,
  getAccount,
  delAccount,
  addAccount,
  updateAccount,
  exportAccount,
  userList
} from '@/api/shop/account'

export default {
  data() {
    return {
      userList: [],
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 总条数
      total: 0,
      // 电商账户表表格数据
      accountList: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      updateFlag: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        dangAccount: undefined,
        dangPassword: undefined,
        fuziAccount: undefined,
        fuziPassword: undefined,
        fuziCookie: undefined,
        deleteFlag: undefined,
        gmtCreate: undefined,
        gmtUpdate: undefined,
        userId: undefined,
        adminId: undefined
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {}
    }
  },
  created() {
    this.getList()
  },
  methods: {
    /** 查询电商账户表列表 */
    getList() {
      this.loading = true
      listAccount(this.queryParams).then((response) => {
        this.accountList = response.data.data.items
        this.total = response.data.data.count
        this.loading = false
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        id: undefined,
        dangAccount: undefined,
        dangPassword: undefined,
        fuziAccount: undefined,
        fuziPassword: undefined,
        fuziCookie: undefined,
        remark: undefined,
        deleteFlag: undefined,
        gmtCreate: undefined,
        gmtUpdate: undefined,
        userId: undefined,
        adminId: undefined
      }
      this.resetForm('form')
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id)
      this.single = selection.length != 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加电商账户表'
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const id = row.id || this.ids.join(',')
      getAccount(id).then((response) => {
        this.form = response.data.data
        userList().then((response) => {
          this.open = true
          this.updateFlag = false
          this.title = '修改电商账户表'
          this.userList = response.data.data
        })
      })
    },
    /** 修改按钮操作 */
    handleUpdateData(row) {
      this.reset()
      const id = row.id || this.ids.join(',')
      getAccount(id).then((response) => {
        this.form = response.data.data
        this.open = true
        this.updateFlag = true
        this.title = '更新电商账户表'
      })
    },
    /** 提交按钮 */
    submitForm: function() {
      this.$refs['form'].validate((valid) => {
        if (valid) {
          if (this.form.id != undefined) {
            updateAccount(this.form).then((response) => {
              if (response.data) {
                this.msgSuccess('修改成功')
                this.open = false
                this.getList()
              } else {
                this.msgError(response.msg)
              }
            })
          } else {
            addAccount(this.form).then((response) => {
              if (response.data) {
                this.msgSuccess('新增成功')
                this.open = false
                this.getList()
              } else {
                this.msgError(response.msg)
              }
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids.join(',')
      this.$confirm(
        '是否确认删除电商账户表编号为"' + ids + '"的数据项?',
        '警告',
        {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }
      )
        .then(function() {
          return delAccount(ids)
        })
        .then(() => {
          this.getList()
          this.msgSuccess('删除成功')
        })
        .catch(function() {})
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams
      this.$confirm('是否确认导出所有电商账户表数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return exportAccount(queryParams)
        })
        .then((response) => {
          this.download(response.data.data)
        })
        .catch(function() {})
    },
    /** 导出按钮操作 */
    handleSee() {
      window.open('../../../../../static/jiaocheng.html')
    }
  }
}
</script>
